@@ -18,13 +18,12 @@ import sys
 import analytics
 
 
-INITIAL_PORT_VALUE = (
-    7860
-)  # The http server will try to open on port 7860. If not available, 7861, 7862, etc.
-TRY_NUM_PORTS = (
-    100
-)  # Number of ports to try before giving up and throwing an exception.
-LOCALHOST_NAME = os.getenv('GRADIO_SERVER_NAME', "127.0.0.1")
+INITIAL_PORT_VALUE = int(os.getenv(
+    'GRADIO_SERVER_PORT', "7860"))  # The http server will try to open on port 7860. If not available, 7861, 7862, etc.
+TRY_NUM_PORTS = int(os.getenv(
+    'GRADIO_NUM_PORTS', "100"))  # Number of ports to try before giving up and throwing an exception.
+LOCALHOST_NAME = os.getenv(
+    'GRADIO_SERVER_NAME', "127.0.0.1")
 GRADIO_API_SERVER = "https://api.gradio.app/v1/tunnel-request"
 
 STATIC_TEMPLATE_LIB = pkg_resources.resource_filename("gradio", "templates/")
@@ -64,7 +63,6 @@ def render_template_with_tags(template_path, context):
     :param template_path: a string with the path to the template file
     :param context: a dictionary whose string keys are the tags to replace and whose string values are the replacements.
     """
-    print(template_path, context)
     with open(template_path) as fin:
         old_lines = fin.readlines()
     new_lines = render_string_or_list_with_tags(old_lines, context)
@@ -89,6 +87,19 @@ def render_string_or_list_with_tags(old_lines, context):
     return new_lines
 
 
+def set_meta_tags(temp_dir, title, description, thumbnail):
+    title = "Gradio" if title is None else title
+    description = "Easy-to-use UI for your machine learning model" if description is None else description
+    thumbnail = "https://gradio.app/static/img/logo_only.png" if thumbnail is None else thumbnail
+
+    index_file = os.path.join(temp_dir, TEMPLATE_TEMP)
+    render_template_with_tags(index_file, {
+        "title": title,
+        "description": description,
+        "thumbnail": thumbnail
+    })
+
+
 def set_config(config, temp_dir):
     config_file = os.path.join(temp_dir, CONFIG_FILE)
     with open(config_file, "w") as output:
@@ -117,6 +128,21 @@ def get_first_available_port(initial, final):
     )
 
 
+def send_prediction_analytics(interface):
+    data = {'title': interface.title,
+            'description': interface.description,
+            'thumbnail': interface.thumbnail,
+            'input_interface': interface.input_interfaces,
+            'output_interface': interface.output_interfaces,
+            }
+    try:
+        requests.post(
+            analytics_url + 'gradio-prediction-analytics/',
+            data=data)
+    except requests.ConnectionError:
+        pass  # do not push analytics if no network
+
+
 def serve_files_in_background(interface, port, directory_to_serve=None, server_name=LOCALHOST_NAME):
     class HTTPHandler(SimpleHTTPRequestHandler):
         """This handler uses server.base_path instead of always using os.getcwd()"""
@@ -160,17 +186,11 @@ def serve_files_in_background(interface, port, directory_to_serve=None, server_n
                 #         f.write(json.dumps(output_flag))
                 #         f.write("\n")
 
-                # Prepare return json dictionary.
                 self.wfile.write(json.dumps(output).encode())
-                data = {'input_interface': interface.input_interfaces,
-                        'output_interface': interface.output_interfaces,
-                        }
-                try:
-                    requests.post(
-                        analytics_url + 'gradio-prediction-analytics/',
-                        data=data)
-                except requests.ConnectionError:
-                    pass  # do not push analytics if no network
+
+                analytics_thread = threading.Thread(
+                    target=send_prediction_analytics, args=[interface])
+                analytics_thread.start()
 
             elif self.path == "/api/flag/":
                 self._set_headers()
@@ -222,9 +242,11 @@ def serve_files_in_background(interface, port, directory_to_serve=None, server_n
     return httpd
 
 
-def start_simple_server(interface, directory_to_serve=None, server_name=None):
+def start_simple_server(interface, directory_to_serve=None, server_name=None, server_port=None):
+    if server_port is None:
+        server_port = INITIAL_PORT_VALUE
     port = get_first_available_port(
-        INITIAL_PORT_VALUE, INITIAL_PORT_VALUE + TRY_NUM_PORTS
+        server_port, server_port + TRY_NUM_PORTS
     )
     httpd = serve_files_in_background(interface, port, directory_to_serve, server_name)
     return port, httpd
