@@ -6,8 +6,8 @@ function gradio(config, fn, target) {
         <div class="input_interfaces">
         </div>          
         <div class="panel_buttons">
-          <input class="submit" type="submit" value="submit"/>
-          <input class="clear" type="reset" value="clear">
+          <input class="clear panel_button" type="reset" value="CLEAR">
+          <input class="submit panel_button" type="submit" value="SUBMIT"/>
         </div>
       </div>
       <div class="panel output_panel">
@@ -17,6 +17,12 @@ function gradio(config, fn, target) {
         </div>
         <div class="output_interfaces">
         </div>
+        <div class="panel_buttons">
+          <input class="screenshot panel_button" type="button" value="SCREENSHOT"/>
+          <div class="screenshot_logo">
+            <img src="static/img/logo_inline.png">
+          </div>
+        </div>
       </div>
     </div>`);
     let io_master = Object.create(io_master_template);
@@ -118,6 +124,21 @@ function gradio(config, fn, target) {
       io_master.last_input = null;
       io_master.last_output = null;
     });
+    if (config["allow_screenshot"]) {
+      target.find(".screenshot").css("visibility", "visible");
+    }
+    target.find(".screenshot").click(function() {
+      $(".screenshot").hide();
+      $(".screenshot_logo").show();
+      html2canvas(target[0], {
+        scrollX: 0,
+        scrollY: -window.scrollY
+      }).then(function(canvas) {
+        saveAs(canvas.toDataURL(), 'screenshot.png');
+        $(".screenshot").show();
+        $(".screenshot_logo").hide();
+      });
+    });
     if (config.live) {
       io_master.gather();
     } else {
@@ -144,4 +165,19 @@ function gradio_url(config, url, target) {
       });
     });              
   }, target);
+}
+function saveAs(uri, filename) {
+  var link = document.createElement('a');
+  if (typeof link.download === 'string') {
+      link.href = uri;
+      link.download = filename;
+      //Firefox requires the link to be in the body
+      document.body.appendChild(link);
+      //simulate click
+      link.click();
+      //remove the link when done
+      document.body.removeChild(link);
+  } else {
+      window.open(uri);
+  }
 }
\ No newline at end of file
